netapp_ontap.models.ipv6_interface_and_gateway API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.ipv6_interface_and_gateway`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class Ipv6InterfaceAndGatewaySchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the Ipv6InterfaceAndGateway object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `address: str GET POST PATCH`

    IPv6 address

    Example: fd20:8b1e:b255:5011:10:141:4:97

  `gateway: str GET POST PATCH`

    The IPv6 address of the default router.

    Example: fd20:8b1e:b255:5011:10::1

  `netmask: Size GET POST PATCH`

    The IPv6 netmask/prefix length. The default value is 64 with a valid range of 1 to 127.

    Example: 64